# pyboolet

Object-oriented wrapper for a more intuitive and readable access to pybullet.

## Installation

`pyboolet` can be installed via pip:

```bash
pip install pyboolet
```

## Usage

For a usage example, please refer to `example/panda_rain_dance.py`.
